import { debugFunction } from '../../util/debugFunction.mjs';
import { deletePath } from '../../util/deletePath.mjs';
import { isFileExists } from '../../util/isFileExists.mjs';
import { parseJSON } from '../../util/parseJSON.mjs';
import { readFile } from '../../util/readFile.mjs';
import { updateJsonFile } from '../../util/updateJsonFile.mjs';

const cleanUpTemplate = async (config) => {
    debugFunction(config.isDebug, { config }, '[PrepareTemplate] cleanUpTemplate');
    if (await isFileExists(config.repositoryMapFilePath)) {
        debugFunction(config.isDebug, { repositoryMapFilePath: config.repositoryMapFilePath }, '[PrepareTemplate] repositoryMapFilePath is exist');
        const repositoryMapFileConfig = await readFile(config.repositoryMapFilePath).then(async (bufferData) => parseJSON(bufferData.toString()));
        const newContent = repositoryMapFileConfig;
        const replaceFile = true;
        newContent.fileMap = [];
        newContent.templateFileList = [];
        await updateJsonFile({
            filePath: config.repositoryMapFilePath,
            config,
            newContent,
            replaceFile,
        });
    }
    if (await isFileExists(config.templateCatalogPath)) {
        debugFunction(config.isDebug, { templateCatalogPath: config.templateCatalogPath }, '[PrepareTemplate] templateCatalogPath is exist');
        try {
            await deletePath(config.templateCatalogPath, true);
            return config;
        }
        catch (error) {
            console.error(`Error isnt exist: ${error.message}`);
            return config;
        }
    }
    debugFunction(config.isDebug, { config }, '[PrepareTemplate] end cleanUpTemplate');
    return config;
};

export { cleanUpTemplate };
