import path__default from 'path';
import { createFile } from '../../util/createFile.mjs';
import { createPath } from '../../util/createPath.mjs';
import { debugFunction } from '../../util/debugFunction.mjs';
import { readFile } from '../../util/readFile.mjs';

const prepareTemplateFile = async ({ config, fileList, }) => {
    debugFunction(config.isDebug, { config, fileList }, '[PrepareTemplate] prepareTemplateFile');
    const templateFileList = [];
    for (const filePath of fileList) {
        const fileName = path__default.basename(filePath) + '-default.md';
        const fileDir = path__default.dirname(filePath);
        const templateFilePath = createPath([config.templateCatalogPath, filePath]);
        templateFileList.push(templateFilePath);
        const content = await readFile(templateFilePath);
        await createFile({
            filePath: createPath([config.templateCatalogPath, fileDir, fileName]),
            content,
            isDebug: config.isDebug,
            options: {
                overwriteFile: true,
            },
        });
    }
    debugFunction(config.isDebug, { config, fileList, templateFileList }, '[PrepareTemplate] END prepareTemplateFile');
    return { config, templateFileList, fileList };
};

export { prepareTemplateFile };
